<?php
/**
 *	Adding a data handler for the Events post type.
 *
 *	@package		Builder Block Events
 *	@subpackage		Editor
 *	@author			Justin Kopepasah
 *	@since			1.0.0
 *
 *	This class handles loading and saving of Events Editor data.
*/

if ( ! class_exists( 'BB_Events_Editor_Data_Handler' ) ) {
	class BB_Events_Editor_Data_Handler {
		private $storage_var = 'builder_block_event_editor';
		private $data_version = '1';
		
		private $defaults = array(
			'it_bb_event_name'			 => 'Event',
			'it_bb_event_name_plural'	 => 'Events',
			'it_bb_event_permalink_base' => 'events',
			'it_bb_event_ended'			 => 'Sorry, this event is over. Check out our other events on the events page.',
			'it_bb_event_postponed'		 => 'This event is postponed until further notice.',
			'it_bb_event_canceled'		 => 'Sorry, this event is canceled.',
			'it_bb_event_orderby'		 => 'start_date',
			'it_bb_event_default_view'	 => 'list_view',
		);
		
		private $storage = null;
		private $options = null;
		
		public function __construct() {
			add_filter( 'it_bb_event_load_data', array( $this, 'load' ) );
			add_action( 'it_bb_event_save_data', array( $this, 'save' ) );
			
			add_filter( "it_storage_get_defaults_{$this->storage_var}", array( $this, 'get_defaults' ) );
			add_action( "it_storage_do_upgrade_{$this->storage_var}", array( $this, 'load_upgrader' ) );
		}
		
		public function load( $options ) {
			if ( is_array( $this->options ) )
				return $this->options;
			
			$this->reload_data();
			
			it_classes_load( 'it-utility.php' );
			
			return ITUtility::merge_defaults( $this->options, $options );
		}
		
		public function save( $options ) {
			it_classes_load( 'it-utility.php' );
			
			$this->options = ITUtility::merge_defaults( $options, $this->defaults );
			
			$this->storage->save( $this->options );
		}
		
		public function get_defaults() {
			return $this->defaults;
		}
		
		public function load_upgrader() {
			require_once( dirname( __FILE__ ) . '/data-upgrader.php' );
		}
		
		private function reload_data() {
			if ( is_null( $this->storage ) ) {
				it_classes_load( 'it-storage.php' );
				$this->storage = new ITStorage2( $this->storage_var, $this->data_version );
			}
			
			$this->options = $this->storage->load();
		}
	}
	
	new BB_Events_Editor_Data_Handler();
}