<?php
/**
 *	Adding a data upgrader for the Events post type.
 *
 *	@package		Builder Block Events
 *	@subpackage		Editor
 *	@author			Justin Kopepasah
 *	@since			1.0.0
 *
 *	This class handles upgrading the stored data from older
 *	formats to the current format. This allows for changing
 *	the format of the data, the index names used, or to do
 *	more complex data migration without worrying about
 *	breaking sites that use the old formats.
*/

if ( ! class_exists( 'BB_Events_Editor_Data_Upgrader' ) ) {
	class BB_Events_Editor_Data_Upgrader {
		var $_var = 'builder_block_event_editor';
		
		function BuilderLayoutStorageUpgrade() {
			add_filter( "it_storage_upgrade_{$this->_var}", array( &$this, 'do_upgrade' ) );
		}
		
		function do_upgrade( $upgrade_data ) {
			$data = $upgrade_data['data'];
			
			if ( version_compare( $data['storage_version'], '1', '<' ) )
				$data = $this->_upgrade_to_1( $data );
			
			$upgrade_data['data'] = $data;
			
			return $upgrade_data;
		}
		
		function _upgrade_to_1( $data ) {
			// Code that updates the data to the new format goes here.
			// Examples of this can be found in
			// Builder/lib/layout-engine/upgrade-storage.php
			
			// Store the new version number in the data.
			$data['storage_version'] = '1';
			
			return $data;
		}
	}
	
	new BB_Events_Editor_Data_Upgrader();
}
