<?php
/**
 *	Adding an editor for the Events post type.
 *
 *	@package        Builder Block Events
 *	@subpackage     Editor
 *	@author         Justin Kopepasah
 *	@since          1.0.0
 *
*/

if ( ! class_exists( 'BB_Events_Editor' ) ) {
	
	class BB_Events_Editor {
		private $options = array();
		private $page_ref = null;
		private $self_link = null;
		private $tabs = array();
		private $active_tab = null;
		private $tabless_self_link = null;
		private $saved_data_message = '';
		private $required_input_error_message = '';
		private $errors = array();
		private $messages = array();
		
		var $_post_type = 'it_bb_event';
		
		public function __construct() {
			add_action( 'admin_menu', array( $this, 'add_admin_pages' ) );
		}
		
		public function init() {
			it_classes_load( 'it-form.php' );
			it_classes_load( 'it-utility.php' );
			it_classes_load( 'it-file-utility.php' );
			
			$this->options = apply_filters( $this->_post_type . '_load_data', array() );
			
			$this->saved_data_message = __( 'Settings saved.' );
			$this->required_input_error_message = __( 'Ensure that all of the required inputs are filled.', 'it-l10n-builder-block-events' );
			
			$this->tabs = array(
				'settings'      => __( 'Settings', 'it-l10n-builder-block-events' ),
				//'help' => __( 'How To', 'it-l10n-builder-block-events' ),
			);
			
			$this->active_tab = ( ! empty( $_REQUEST['editor_tab'] ) ) ? $_REQUEST['editor_tab'] : key( $this->tabs );
			
			// $this->tabless_self_link = array_shift( explode( '?', $_SERVER['REQUEST_URI'] ) ) . '?post_type=' . $this->_post_type . '&page=' . $_REQUEST['page'];
			$this->tabless_self_link = $_SERVER['REQUEST_URI'];
			$this->self_link = $this->tabless_self_link;
			
			if ( $this->active_tab != key( $this->tabs ) )
				$this->self_link .= '&editor_tab=' . urlencode( $this->active_tab );
			
			$this->plugin_url = ITFileUtility::get_url_from_file( dirname( __FILE__ ) );
		}
		
		public function add_admin_pages() {
			$this->_page_ref = add_submenu_page( "edit.php?post_type={$this->_post_type}", 'Settings', 'Settings', 'edit_themes', 'bb-events-editor', array( $this, 'index' ) );
			
			add_action( "load-{$this->_page_ref}", array( $this, 'init' ) );
			add_action( "admin_print_scripts-{$this->_page_ref}", array( $this, 'add_scripts' ) );
			add_action( "admin_print_styles-{$this->_page_ref}", array( $this, 'add_styles' ) );			
		}
		
		public function add_scripts() {
			$params = array(
				'required_input_error_string' => $this->required_input_error_message,
			);
			
			/*
				TODO Find out if we are using this.
			*/
			wp_enqueue_script( 'it-bb-events-script', "{$this->plugin_url}/js/editor.js" );
			wp_localize_script( 'it-bb-events-script', 'BB_Events_Editor', $params );
			
			ITUtility::add_tooltip_scripts();
		}
		
		public function add_styles() {
			wp_enqueue_style( 'bb-events-style', "{$this->plugin_url}/css/editor.css" );
			ITUtility::add_tooltip_styles();
		}
		
		public function index() {
			if ( 'help' == $this->active_tab ) {
				if ( ! empty( $_POST['save'] ) )
					$this->help_save_data();
				else
					$this->help_index();
			}
			else {
				if( ! empty( $_POST['save'] ) )
					$this->settings_save_data();
				else
					$this->settings_index();
			}
		}
		
		public function settings_save_data() {
			ITForm::check_nonce( 'save-primary' );
			
			$data = ITForm::get_post_data();
			
			$required_inputs = array( 
				$this->_post_type . '_permalink_base',
				$this->_post_type . '_name', 
				$this->_post_type . '_name_plural',
				$this->_post_type . '_ended',
				$this->_post_type . '_postponed',
				$this->_post_type . '_canceled',
			);
			$has_errors = false;
			
			foreach ( $required_inputs as $var ) {
				if ( empty( $data[$var] ) ) {
					ITUtility::show_error_message( $this->required_input_error_message );
					$has_errors = true;
					break;
				}
			}
			
			// Make sure users enter both the API key and User key.
			if ( empty( $data['eventbrite_api_key'] ) xor empty( $data['eventbrite_api_user_key'] ) ) {
				ITUtility::show_error_message( __( 'Both the Eventbrite API Key and User Key must be set.', 'it-l10n-builder-block-events' ) );
				$has_errors = true;
			}
			
			if ( ! empty( $data['eventbrite_api_key'] ) && ! empty( $data['eventbrite_api_user_key'] ) ) {
				
				$authentication_tokens = array(
					'app_key'  => $data['eventbrite_api_key'],
					'user_key' => $data['eventbrite_api_user_key'],
				);
				
				$Eventbrite = new Eventbrite( $authentication_tokens );
				
				$event_search = $Eventbrite->event_search();
				
				if ( ! empty( $event_search->error ) ) {
					$type = preg_replace( '/\bapplication\b/i', 'API', $event_search->error->error_type );
					$message = preg_replace( '/\bapplication\b/i', 'API', $event_search->error->error_message );
					$message = preg_replace( '/\buser_key\b/i', 'API User Key', $message );
					
					ITUtility::show_error_message( sprintf( __( 'Eventbrite validation error: %1$s: %2$s', 'it-l10n-builder-block-events' ), $type, $message ) );
					$has_errors = true;
					
				}
			}
			
			// Add in any validation checks here. Such as ensuring that an input that stores a number
			// contains just a number. Show errors for any issues.
			if ( $has_errors ) {
				$this->settings_index( $data );
				return;
			}
			
			if ( $data[$this->_post_type . '_permalink_base'] != $this->options[$this->_post_type . '_permalink_base'] )
				update_option( $this->_post_type . '_force_rewrite_flush', true );
			
			$this->options = ITUtility::merge_defaults( $data, $this->options );
			
			do_action( $this->_post_type . '_save_data', $this->options );
			ITUtility::show_status_message( $this->saved_data_message );
			
			$this->settings_index();
		}
		
		public function settings_index( $options = null ) {
			if ( ! is_array( $options ) ) {
				$options = $this->options;
			}
			
			$form = new ITForm( $options );
			
			?>
				<div class="wrap">
					<?php $form->start_form( array( 'class' => 'validate' ), 'save-primary' ); ?>
						<?php screen_icon( $screen = $this->_post_type . '_settings' ); ?>
						<h2><?php _e( 'Settings', 'it-l10n-builder-block-events' ); ?></h2>
						
						<!-- <div id="js-error-response"></div> -->
						
						<div class="divider-wrap first">
							<h3><?php _e( 'Eventbrite Settings', 'it-l10n-builder-block-events' ); ?></h3>
							<p><?php _e( 'Builder Block Events requires an Eventbrite API Key and your personal API User Key in order use use Eventbrite widgets on your ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
							<table class="form-table">
								<tr>
									<th scope="row"><label for="eventbrite_api_key"><?php _e( 'Eventbrite API Key', 'it-l10n-builder-block-events' ); ?></label></th>
									<td><?php $form->add_text_box( 'eventbrite_api_key' ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="eventbrite_api_user_key"><?php _e( 'Eventbrite API User Key', 'it-l10n-builder-block-events' ); ?></label></th>
									<td><?php $form->add_text_box( 'eventbrite_api_user_key' ); ?></td>
								</tr>
							</table>
							<p><?php _e( 'Grab your API Key <a href="https://www.eventbrite.com/api/key">here</a>.', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(first you must create one).', 'it-l10n-builder-block-events' ); ?></p>
							<p><?php _e( 'You API User Key <a href="http://www.eventbrite.com/userkeyapi">here</a>.', 'it-l10n-builder-block-events' ); ?></p>
						</div>
						
						<div class="divider-wrap">
							<h3><?php _e( 'Post type name and name plural', 'it-l10n-builder-block-events' ); ?></h3>
							<p><?php _e( 'If you want to change the name and plural name of your the post type, you can do so here.', 'it-l10n-builder-block-events' ); ?></p>
							<table class="form-table">
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_name"><?php _e( 'Name', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_box( $this->_post_type . '_name' ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_name_plural"><?php _e( 'Plural Name', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_box( $this->_post_type . '_name_plural' ); ?></td>
								</tr>
							</table>
						</div>
						
						<div class="divider-wrap">
							<h3><?php _e( 'Permalink Structure', 'it-l10n-builder-block-events' ); ?></h3>
							<?php if ( get_option('permalink_structure') != '' ) : ?>
								<p><?php _e( 'You can change the permalink structure for your ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) .' here.', 'it-l10n-builder-block-events' ); ?></p>
								<table class="form-table">
									<tr>
										<th scope="row"><label for="<?php echo $this->_post_type ?>_permalink_base"><?php _e( 'Permalink slug', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
										<td><?php $form->add_text_box( $this->_post_type . '_permalink_base' ); ?></td>
									</tr>
									<tr>
										<th scope="row"><?php _e( 'Current Permalink:', 'it-l10n-builder-block-events' ); ?></th>
										<td><span class="description"><a href="<?php echo bloginfo( 'url' ); ?>/<?php echo $this->options[$this->_post_type . '_permalink_base']; ?>/" target="_blank"><?php echo bloginfo( 'url' ); ?>/<?php echo $this->options[$this->_post_type . '_permalink_base']; ?></a></span></td>
									</tr>
								</table>
							<?php else : ?>
								<p><?php _e( 'In order to change the permalink structure for your ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) .', you must first set up pretty permalinks on your <a href="' . get_admin_url( false, 'options-permalink.php' ) . '">permalink settings page</a>.', 'it-l10n-builder-block-events' ); ?></p>
								<table class="form-table">
									<tr>
										<th scope="row"><?php _e( 'Current Permalink:', 'it-l10n-builder-block-events' ); ?></th>
										<td><span class="description"><a href="<?php echo bloginfo( 'url' ); ?>/?post_type=<?php echo $this->_post_type ?>" target="_blank"><?php echo bloginfo( 'url' ); ?>/?post_type=<?php echo $this->_post_type ?></a></span></td>
									</tr>
								</table>
							<?php endif; ?>
						</div>
						
						<div class="divider-wrap">
							<h3><?php _e( 'List or Calendar View', 'it-l10n-builder-block-events' ); ?></h3>
							<p><?php _e( 'Set the default view for you ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) . ' archive view.', 'it-l10n-builder-block-events' ); ?></p>
							<table class="form-table">
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_default_view-list_view"><?php _e( 'List View', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(default)' ); ?></span></label></th>
									<td><?php $form->add_radio( $this->_post_type . '_default_view', 'list_view' ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_default_view-calendar_view"><?php _e( 'Calendar View', 'it-l10n-builder-block-events' ); ?></label></th>
									<td><?php $form->add_radio( $this->_post_type . '_default_view', 'calendar_view' ); ?></td>
								</tr>
							</table>
						</div>
						
						<div class="divider-wrap">
							<h3><?php _e( 'Display Order', 'it-l10n-builder-block-events' ); ?></h3>
							<p><?php _e( 'Set the order in which you want your ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) . ' to display for the list view.', 'it-l10n-builder-block-events' ); ?></p>
							<table class="form-table">
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_orderby-start_date"><?php _e( 'Start Date', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(default)' ); ?> <?php ITUtility::add_tooltip( 'Using this option will not display ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) . ' older than today\'s date.' ); ?></span></label></th>
									<td><?php $form->add_radio( $this->_post_type . '_orderby', 'start_date' ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_orderby-publish_date"><?php _e( 'Publish Date', 'it-l10n-builder-block-events' ); ?></label></th>
									<td><?php $form->add_radio( $this->_post_type . '_orderby', 'publish_date' ); ?></td>
								</tr>
							</table>
						</div>
						
						<div class="divider-wrap last">
							<h3><?php _e( 'Notification Messages', 'it-l10n-builder-block-events' ); ?></h3>
							
							<table class="form-table">
								<p><?php _e( 'There are three different notifications for your ' . strtolower( $this->options[$this->_post_type . '_name_plural'] ) . ': ended, postponed and canceled. Here you can set a custom notification messages.', 'it-l10n-builder-block-events' ); ?></p>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_ended"><?php _e( 'Ended', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_area( $this->_post_type . '_ended', array( 'style' => 'min-width:300px;' ) ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_postponed"><?php _e( 'Postoned', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_area( $this->_post_type . '_postponed', array( 'style' => 'min-width:300px;' ) ); ?></td>
								</tr>
								<tr>
									<th scope="row"><label for="<?php echo $this->_post_type ?>_canceled"><?php _e( 'Canceled', 'it-l10n-builder-block-events' ); ?> <span class="description"><?php _e( '(required)' ); ?></span></label></th>
									<td><?php $form->add_text_area( $this->_post_type . '_canceled', array( 'style' => 'min-width:300px;' ) ); ?></td>
								</tr>
							</table>
						</div>
						
						<p class="submit">
							<?php $form->add_submit( 'save', array( 'value' => __( 'Save Changes' ), 'class' => 'button-primary' ) ); ?>
						</p>
					<?php $form->end_form(); ?>
				</div>
			<?php
			
		}
		
		public function help_save_data() {
			
		}
		
		public function help_index() {
		
		
		}
		
		public function print_tabs() {
			echo "<h2 class='nav-tab-wrapper'>";
			
			foreach ( (array) $this->tabs as $var => $name ) {
				$link = $this->tabless_self_link;
				if ( $var != key( $this->tabs ) )
					$link .= '&editor_tab=' . urlencode( $var );
				
				$class = 'nav-tab' . ( ( $var === $this->active_tab ) ? ' nav-tab-active' : '' );
				
				echo "<a class='$class' href='$link'>$name</a>";
			}
			
			echo "</h2>\n";
		}
	}
	
	new BB_Events_Editor();
}
