<?php
/**
 *	Register the events post type.
 *
 *	@package		Builder Block Events
 *	@subpackage		Post Types
 *	@author			Justin Kopepasah
 *	@since			1.0.0
 *
*/

if ( ! class_exists( 'BB_Events_Post_Type' ) ) {
	it_classes_load( 'it-post-type.php' );
	
	class BB_Events_Post_Type extends ITPostType {
		var $_file = __FILE__;
		
		var $_var = 'it_bb_event';
		var $_name = 'Event';
		var $_name_plural = 'Events';
		
		var $_settings = array(
			'rewrite'	  	=> array(
				'slug'			=> 'events',
			),
			'supports'	  	=> array( 'title', 'editor', 'thumbnail', 'excerpt' ),
			'menu_icon'   	=> 'images/event-icon-inactive.png',
			'has_archive' 	=> true,
		);
		
		var $_meta_boxes = array(
			'map' => array(
				'title'    => 'Location',
				'callback' => 'render_meta_box_map',
				'context'  => 'normal',
				'priority' => 'default',
			),
			'notification' => array(
				'title'    => 'Notifications',
				'callback' => 'render_meta_box_notification',
				'context'  => 'side',
				'priority' => 'default',
			),
			'date' => array(
				'title' => 'Date',
				'callback' => 'render_meta_box_date',
				'context'  => 'side',
				'priority' => 'default',
			),
			'gform' => array(
				'title'    => 'Gravity Forms',
				'callback' => 'render_meta_box_gfrom_select',
				'context'  => 'side',
				'priority' => 'default',
			),
			'eventbrite' => array(
				'title'    => 'Eventbrite Widgets',
				'callback' => 'render_meta_box_eventbrite',
				'context'  => 'side',
				'priority' => 'default',
			),
		);
		
		var $_menu_pages = array(
			'getting_started' => array(
				'menu_title' => 'Start Here',
				'page_title' => 'Start Here',
				'capability' => 'edit_themes',
				'callback'   => 'getting_started_index',
			),
		);
		
		var $_editor_load_jquery = true;
		var $_public_load_jquery = true;
		var $_has_custom_screen_icon = true;
		
		function _load() {
			parent::_load();
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			$this->_name = $settings[$this->_var . '_name'];
			$this->_name_plural = $settings[$this->_var . '_name_plural'];
			
			$this->_settings['rewrite']['slug'] = $settings[$this->_var . '_permalink_base'];	
			
			add_action( "wp_ajax_{$this->_var}_load_calendar_events", array( $this, 'load_ajax_calendar_events' ) );
			add_action( "wp_ajax_nopriv_{$this->_var}_load_calendar_events", array( $this, 'load_ajax_calendar_events' ) );
			
			add_filter( "{$this->_var}_get_post_meta_values", array( $this, 'get_post_meta_values' ), 10, 2 );
			
			if ( ! is_admin() && $settings['it_bb_event_orderby'] == 'start_date' ) {
				add_action( 'pre_get_posts', array( $this, 'add_archive_query_filters' ) );
			}
		}
		
		function get_post_meta_values( $options = array(), $post_id = null ) {
			if ( is_null( $post_id ) ) {
				global $post;
				
				if ( ! empty( $post->ID ) )
					$meta = get_post_meta( $post->ID, '_it_options', true );
			}
			else
				$meta = get_post_meta( $post_id, '_it_options', true );
			
			if ( isset( $meta ) ) {
				$default_meta = $this->get_default_post_meta_values();
			
				$meta = ITUtility::merge_defaults( $meta, $default_meta );
			} else {
				$meta = $this->get_default_post_meta_values();
			}
			
			return $meta;
		}
		
		function get_default_post_meta_values() {
			$default = array();
			
			return $default;
		}
		
		function add_archive_query_filters( $query ) {
			if ( ! isset( $query->query ) || ! isset( $query->query['post_type'] ) || ( $query->query['post_type'] != $this->_var || ! is_post_type_archive( $this->_var ) ) )
				return;
			
			add_filter( 'posts_where', array( $this, 'filter_archive_query_where' ) );
			add_filter( 'posts_join', array( $this, 'filter_archive_query_join' ) );
			add_filter( 'posts_orderby', array( $this, 'filter_archive_query_orderby' ) );
			add_filter( 'posts_groupby', array( $this, 'filter_archive_query_groupby' ) );
			add_filter( 'posts_fields', array( $this, 'filter_archive_query_fields' ) );
			
			add_action( 'posts_selection', array( $this, 'remove_archive_query_filters' ) );
		}
		
		function remove_archive_query_filters( $query ) {
			remove_filter( 'posts_where', array( $this, 'filter_archive_query_where' ) );
			remove_filter( 'posts_join', array( $this, 'filter_archive_query_join' ) );
			remove_filter( 'posts_orderby', array( $this, 'filter_archive_query_orderby' ) );
			remove_filter( 'posts_groupby', array( $this, 'filter_archive_query_groupby' ) );
			remove_filter( 'posts_fields', array( $this, 'filter_archive_query_fields' ) );
			
			remove_action( 'posts_selection', array( $this, 'remove_archive_query_filters' ) );
		}
		
		function filter_archive_query_where( $where ) {
			global $wpdb;
			
			$date = date( 'Y-m-d' );
			
			$where .= "AND ( ( $wpdb->postmeta.meta_key='_{$this->_var}_start_timestamp' AND $wpdb->postmeta.meta_value>='$date' ) OR ( $wpdb->postmeta.meta_key='_{$this->_var}_end_timestamp' AND $wpdb->postmeta.meta_value>='$date' ) )";
			
			return $where;
		}
		
		function filter_archive_query_join( $join ) {
			global $wpdb, $post;	
			
			$join .= "LEFT JOIN $wpdb->postmeta ON $wpdb->posts.ID=$wpdb->postmeta.post_id ";
			
			return $join;
		}
		
		function filter_archive_query_orderby( $orderby ) {
			global $wpdb;
			
			$orderby = "$wpdb->postmeta.meta_value ASC ";
			
			return $orderby;
		}
		
		function filter_archive_query_groupby( $groupby ) {
			global $wpdb;
			
			if ( ! empty( $groupby ) )
				$groupby = ", $groupby";
			$groupby = "$wpdb->posts.ID$groupby";
			
			return $groupby;
		}
		
		function filter_archive_query_fields( $fields ) {
			global $wpdb;
			
			$fields .= ", $wpdb->postmeta.meta_value";
			
			return $fields;
		}
		
		function load_ajax_calendar_events() {
			// Get the start and end dates.
			// Drop the time component to normalize to midnight.
			// Pad out the range by a day in order to do a simple compensation for time zone differences.
			$start = date( 'Y-m-d', $_GET['start'] - 86400 ) . ' 00:00:00';
			$end = date( 'Y-m-d', $_GET['end'] + 86400 ) . ' 23:59:59';
			
			
			header( 'content-type: text/plain' );
			
			
			$query_args = array(
				'post_type'           => $this->_var,
				'post_status'         => 'publish',
				'ignore_sticky_posts' => true,
				'posts_per_page'      => -1,
				'meta_query'          => array(
					array(
						'key'     => "_{$this->_var}_start_timestamp",
						'value'   => $start,
						'compare' => '>=',
					),
					array(
						'key'     => "_{$this->_var}_start_timestamp",
						'value'   => $end,
						'compare' => '<=',
					),
				),
			);
			
			$events = get_posts( $query_args );
			
			if ( ! is_array( $events ) )
				exit;
			
			
			$calendar_settings = array(
				'default'   => array(
					'class_name'       => '',
					'background_color' => '#555',
					'border_color'     => '#555',
					'text_color'       => '#FFF',
				),
				'canceled'  => array(
					'class_name'       => 'error',
					'background_color' => '#FFC8C8',
					'border_color'     => '#FFC8C8',
					'text_color'       => '#8A1F11',
				),
				'postponed' => array(
					'class_name'       => 'notice',
					'background_color' => '#FFFECF',
					'border_color'     => '#F3EF39',
					'text_color'       => '#514721',
				),
			);
			$calendar_settings = apply_filters( "{$this->_var}_filter_calendar_settings", $calendar_settings );
			
			
			$json_data = '';
			
			foreach ( (array) $events as $event ) {
				$event_options = $this->get_post_meta_values( array(), $event->ID );
				
				if ( ! empty( $event_options['event_canceled'] ) )
					$settings = $calendar_settings['canceled'];
				else if ( ! empty( $event_options['event_postponed'] ) )
					$settings = $calendar_settings['postponed'];
				else
					$settings = $calendar_settings['default'];
				
				$event_info = array(
					'id'              => $event->ID,
					'title'           => $event->post_title,
					'start'           => $event_options['event_start_date'],
					'end'             => $event_options['event_end_date'],
					'url'             => get_permalink( $event->ID ),
					'allDay'          => 'false',
					'className'       => $settings['class_name'],
					'backgroundColor' => $settings['background_color'],
					'borderColor'     => $settings['border_color'],
					'textColor'       => $settings['text_color'],
				);
				
				
				if ( ! empty( $json_data ) )
					$json_data .= ',';
				
				$json_entry = '';
				
				foreach ( $event_info as $var => $val ) {
					if ( ! empty( $json_entry ) )
						$json_entry .= ',';
					$json_entry .= '"' . str_replace( '"', '\"', $var ) . '":"' . str_replace( '"', '\"', $val ) . '"';
				}
				
				$json_data .= '{' . $json_entry . '}';
			}
			
			$json_data = "[$json_data]";
			
			echo $json_data;
			
			
			exit;
		}
		
		function init() {
			if ( false !== get_option( $this->_var . '_force_rewrite_flush' ) ) {
				flush_rewrite_rules( false );
				delete_option( $this->_var . '_force_rewrite_flush' );
			}
 		}
		
		function admin_print_scripts() {
			wp_enqueue_script( 'google-maps-api', 'http://maps.google.com/maps/api/js?sensor=true' );
			wp_enqueue_script( 'date-time-js', ITFileUtility::get_url_from_file( dirname( $this->_file ) . '/js/date-time.js' ), array( 'jquery-ui-widget', 'jquery-ui-position', 'jquery-ui-sortable' ) );
			
			ITUtility::add_tooltip_scripts();
			ITUtility::add_tooltip_styles();
		}
		
		function print_scripts() {
			$post_options = $this->get_post_meta_values();
			
			if ( ! empty( $post_options['gform_enable_ajax'] ) ) {
				$form_ajax = true;
			}
			else {
				$form_ajax = false;
			}
			
			if ( is_singular( $this->_var ) ) {
				wp_enqueue_script( 'google-maps-api', 'http://maps.google.com/maps/api/js?sensor=true', array(), null );
				if ( class_exists( 'RGForms' ) && isset( $post_options[ 'gform_register' ] ) && $post_options['gform_register'] != 'invert-custom' ) {
					gravity_form_enqueue_scripts( $post_options['gform_register'], $form_ajax );
				}
			}
				
			if ( is_post_type_archive( $this->_var ) )
				wp_enqueue_script( 'fullcalendar', ITFileUtility::get_url_from_file( dirname( $this->_file ) . '/js/jquery.fullcalendar.min.js' ), array( 'jquery' ) );
		}
		
		function validate_meta_box_options( $options, $post_id ) {
			
			// Unset the search option.
			unset( $options['search_address'] );
			
			// Set some empty strings for the gravity forms args.
			if ( class_exists( 'RGForms' ) ) {
				if ( ! isset( $options[ 'gform_display_title' ] )  ) {
					$options[ 'gform_display_title' ] = '';
				}
				if ( ! isset( $options[ 'gform_display_description' ] )  ) {
					$options[ 'gform_display_description' ] = '';
				}
				if ( ! isset( $options[ 'gform_enable_ajax' ] )  ) {
					$options[ 'gform_enable_ajax' ] = '';
				}
			}
			
			if ( strtotime( $options[ 'event_end_date' ] ) < strtotime( $options[ 'event_start_date' ] ) ) {
				$options[ 'event_end_date' ] = $options[ 'event_start_date' ];
			}
			
			// Set up event start and end timestamps.
			$options['event_start_timestamp'] = get_gmt_from_date( $options['event_start_date'] . ' 00:00:00' );
			$options['event_end_timestamp'] = get_gmt_from_date( $options['event_end_date'] . ' 00:00:00' );
			
			update_post_meta( $post_id, '_' . $this->_var . '_start_timestamp', $options['event_start_timestamp'] );
			update_post_meta( $post_id, '_' . $this->_var . '_end_timestamp', $options['event_end_timestamp'] );
			
			return $options;
		}
		
		function getting_started_index() {
			global $title;
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			$venue_editor = new BB_Events_Venue_Editor();
			$venue_settings = apply_filters( $venue_editor->_post_type . '_load_data', array() );
			
			$images = array(
				'date_box'           => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/date-time-meta-box.png" alt="" />',
				'select_date'        => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/select-a-date.png" alt="" />',
				'select_time'        => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/select-a-time.png" alt="" />',
				'location_box'       => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/location-meta-box.png" alt="" />',
				'eventbrite_box'     => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/eventbrite-meta-box.png" alt="" />',
				'gravity_box'        => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/gravity-meta-box.png" alt="" />',
				'venue_location_box' => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/venue-map-meta-box.png" alt="" />',
				'event_menu_box'     => '<img src="'. ITFileUtility::get_url_from_file( dirname( $this->_file ) ) . '/images/event-menu-meta.png" alt="" />',
			);
			
			?>
				<div class="wrap <?php echo $this->_var  ?>-help-wrap">
					<?php screen_icon( $this->_var ); ?>
					<h2><?php _e( 'Start Here', 'it-l10n-builder-block-events' ); ?></h2>
					
					<div class="divider-wrap quick-links">
						<h3><?php _e( 'Quick Links', 'it-l10n-builder-block-events' ); ?></h3>
						<ul>
							<li><a href="#creating-new-event"><?php _e( 'Creating a New ' . $settings[ $this->_var . '_name'], 'it-l10n-builder-block-events' ); ?></a></li>
							<li><a href="#creating-new-venue"><?php _e( 'Creating a New ' . $venue_settings[$venue_editor->_post_type . '_name'], 'it-l10n-builder-block-events' ); ?></a></li>
							<li><a href="#locating-you-events"><?php _e( 'Locating your ' . $settings[$this->_var . '_name_plural'], 'it-l10n-builder-block-events' ); ?></a></li>
							<li><a href="#events-in-menu"><?php _e( 'Add ' . $settings[$this->_var . '_name_plural'] . ' Archive to the Menu', 'it-l10n-builder-block-events' ); ?></a></li>
							<li><a href="#event-video-overviews"><?php _e( 'Video Overview', 'it-l10n-builder-block-events' ); ?></a></li>
						</ul>
					</div>
					
					<div class="divider-wrap">
						<h3 id="creating-new-event"><?php _e( 'Creating a New ' . $settings[$this->_var . '_name'] . '', 'it-l10n-builder-block-events' ); ?></h3>
						<p><?php _e( 'Creating a new ' . strtolower( $settings[$this->_var . '_name'] ) . ' is just like writing a post or creating a page (with a few little extras added in). You can create a new ' . strtolower( $settings[$this->_var . '_name'] ) . ' by following the steps below.', 'it-l10n-builder-block-events' ); ?></p>
						<ul>
							<li><strong><?php _e( 'Click "Add New" under the ' . $settings[$this->_var . '_name'] . ' menu.', 'it-l10n-builder-block-events' ); ?></strong></li>
							<li><strong><?php _e( 'Give your ' . strtolower( $settings[$this->_var . '_name'] ) . ' a title and write information about in the content editor.', 'it-l10n-builder-block-events' ); ?></strong></li>
							<li>
								<strong><?php _e( 'Find the Date meta box.', 'it-l10n-builder-block-events' ); ?></strong> <?php ITUtility::add_tooltip( $images['date_box'] ); ?>
								<ul>
									<li><?php _e( 'Select a start and end date for the ' . strtolower( $settings[$this->_var . '_name'] ) . '.', 'it-l10n-builder-block-events' ); ?> <?php ITUtility::add_tooltip( $images['select_date'] ); ?></li>
								</ul>
							</li>
							<li>
								<strong><?php _e( 'Find the Location meta box.', 'it-l10n-builder-block-events' ); ?></strong> <?php ITUtility::add_tooltip( $images['location_box'] ); ?>
								<ul>
									<li><?php _e( 'Select a ' . $venue_settings[$venue_editor->_post_type . '_name'] . ' (see below) or use a custom address.', 'it-l10n-builder-block-events' ); ?></li>
									<ul>
										<p class="stay-or-skip"><?php _e( 'If you select <strong>Use Custom Address</strong>, follow these steps. If not, proceed to step 5.', 'it-l10n-builder-block-events' ); ?></p>
										<li><?php _e( 'Enter your address as you would like it to appear on your site. An example address is provided to the right.', 'it-l10n-builder-block-events' ); ?></li>
										<li><?php _e( 'Enter your location in the text box above the map and press enter.', 'it-l10n-builder-block-events' ); ?></li>
										<li><?php _e( 'Reposition the PIN to the exact location you want to display.', 'it-l10n-builder-block-events' ); ?></li>
									</ul>
								</ul>
							</li>
							<li><?php _e( '<strong>Set a Featured Image</strong> <span class="description">(optional)</span>', 'it-l10n-builder-block-events' ); ?></li>
							<?php if ( class_exists( 'RGForms' ) ) : ?>
								<li><?php _e( '<strong>Find the Gravity Forms Meta Box</strong> <span class="description">(optional)</span>', 'it-l10n-builder-block-events' ); ?> <?php ITUtility::add_tooltip( $images['gravity_box'] ); ?></li></li>
							<?php endif; ?>
							<?php if ( ! empty( $settings['eventbrite_api_key'] ) ) : ?>
								<li><?php _e( '<strong>Find the Eventbrite Meta Box</strong> <span class="description">(optional)</span>', 'it-l10n-builder-block-events' ); ?> <?php ITUtility::add_tooltip( $images['eventbrite_box'] ); ?></li></li>
							<?php endif; ?>
							<li><?php _e( '<strong>Publish your ' . $settings[$this->_var . '_name'] . '!</strong>', 'it-l10n-builder-block-events' ); ?></li>
						</ul>
					</div>
					
					<div class="divider-wrap">
						<h3 id="creating-new-venue"><?php _e( 'Creating a New ' . $venue_settings[$venue_editor->_post_type . '_name'], 'it-l10n-builder-block-events' ); ?></h3>
						<p><?php _e( $venue_settings[$venue_editor->_post_type . '_name_plural'] . ' are a way of creating default locations to set for your ' . strtolower( $settings[$this->_var . '_name_plural'] ) . '. You can create a new ' . $venue_settings[$venue_editor->_post_type . '_name'] . ' by following the steps below.', 'it-l10n-builder-block-events' ); ?></p>
						<ul>
							<li><strong><?php _e( 'Click "Add New" under the ' . $venue_settings[$venue_editor->_post_type . '_name_plural'] . ' menu.', 'it-l10n-builder-block-events' ); ?></strong></li>
							<li><strong><?php _e( 'Give your ' . $venue_settings[$venue_editor->_post_type . '_name'] . ' a title.', 'it-l10n-builder-block-events' ); ?></strong></li>
							<li>
								<strong><?php _e( 'Find the Location meta box.', 'it-l10n-builder-block-events' ); ?></strong> <?php ITUtility::add_tooltip( $images['venue_location_box'] ); ?>
								<ul>
									<li><?php _e( 'Enter your address as you would like it to appear on your site. An example address is provided to the right.', 'it-l10n-builder-block-events' ); ?></li>
									<li><?php _e( 'Enter your location in the text box above the map and press enter.', 'it-l10n-builder-block-events' ); ?></li>
									<li><?php _e( 'Reposition the PIN to the exact location you want to display.', 'it-l10n-builder-block-events' ); ?></li>
								</ul>
							</li>
							<li><?php _e( '<strong>Publish your ' . $venue_settings[$venue_editor->_post_type . '_name'] . '!</strong>', 'it-l10n-builder-block-events' ); ?></li>
						</ul>
					</div>
					
					<div class="divider-wrap">
						<h3 id="locating-you-events"><?php _e( 'Locating Your ' . $settings[$this->_var . '_name_plural'] . '', 'it-l10n-builder-block-events' ); ?></h3>
						<p><?php _e( 'You can find a list of your ' . strtolower( $settings[$this->_var . '_name_plural'] ) . ' located at the address below. This is the archive of all your ' . strtolower( $settings[$this->_var . '_name_plural'] ) . ' which are displayed as a list or calendar view.', 'it-l10n-builder-block-events' ); ?></p>
						<p><?php _e( 'Your ' . $settings[$this->_var . '_name_plural'] . ' archive location:', 'it-l10n-builder-block-events' ); ?> <em><a href="<?php echo bloginfo( 'url' ); ?>/<?php echo $settings[$this->_var . '_permalink_base']; ?>" target="_blank"><?php echo bloginfo( 'url' ); ?>/<?php echo $settings[$this->_var . '_permalink_base']; ?></a></em></p>
					</div>
					
					<div class="divider-wrap">
						<h3 id="events-in-menu"><?php _e( 'Add ' . $settings[$this->_var . '_name_plural'] . ' Archive to the Menu', 'it-l10n-builder-block-events' ); ?></h3>
						<p><?php _e( 'If you are using the WordPress menu editor, you can add the ' . strtolower( $settings[$this->_var . '_name_plural'] ) . ' to your menu with these following steps.', 'it-l10n-builder-block-events' ); ?></p>
						<ul>
							<li><strong><?php _e( 'Head over to the <a href="' . get_admin_url( false, 'nav-menus.php' ) . '">menu editor</a>.', 'it-l10n-builder-block-events' ); ?></strong></li>
							<li>
								<strong><?php _e( 'Find the ' . $settings[$this->_var . '_name_plural'] . ' menu meta box.', 'it-l10n-builder-block-events' ); ?></strong> <?php ITUtility::add_tooltip( $images['event_menu_box'] ); ?>
								<ul>
									<li><?php _e( 'Click the <em>View All</em> tab.', 'it-l10n-builder-block-events' ); ?></li>
									<li><?php _e( 'Select All ' . $settings[$this->_var . '_name_plural'] . ' and click <em>Add to Menu</em>.', 'it-l10n-builder-block-events' ); ?></li>
								</ul>
							</li>
							<li><?php _e( '<strong>Save your Menu!</strong>', 'it-l10n-builder-block-events' ); ?></li>
						</ul>
					</div>
					
					<div class="divider-wrap last" id="start_here_frame_container">
						<h3 id="event-video-overviews"><?php _e( 'Video Overview', 'it-l10n-builder-block-events' ); ?></h3>
						<iframe id="start_here_frame" src="http://ithemes.com/start-here-tuts/blocks/events/videos.html" frameborder="0" allowtransparency="true"></iframe>
					</div>
				</div>
			<?php
		}
		
		// Event map meta box.
		function render_meta_box_map( $post, $form, $options ) {
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			$venue_editor = new BB_Events_Venue_Editor();
			$venue_settings = apply_filters( $venue_editor->_post_type . '_load_data', array() );
			
			// The query for default locations.
			$venues = new WP_Query( array( 'post_type' => 'it_bb_event_venue', 'posts_per_page' => -1 ) );
			
			$venue_options = array(
				'Custom' => array(
					'custom' => 'Use Custom Address',
				),
				$venue_settings[$venue_editor->_post_type . '_name_plural'] => array(),
			);
			
			foreach ( $venues->posts as $venue ) {
				$venue_options['' . $venue_settings[$venue_editor->_post_type . '_name_plural'] . ''][ absint( $venue->ID ) ] = esc_html( $venue->post_title );
			}
			
			if ( $venues->post_count > 0 ) {
				?>
					<p><?php _e( 'Select a ' . $venue_settings[$venue_editor->_post_type . '_name'] . ' or use a custom address for this ' . strtolower( $settings[$this->_var . '_name'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
					<p><?php $form->add_drop_down( 'default_location', $venue_options ); ?></p>
				<?php
			}
			else {
				?>
					<p><?php _e( '<strong>You have not added any ' . $venue_settings[$venue_editor->_post_type . '_name_plural'] . '. </strong>If you use a specific ' . $venue_settings[$venue_editor->_post_type . '_name'] . ' frequently, add it to your ' . $venue_settings[$venue_editor->_post_type . '_name_plural'] . ' and eliminate the need to write the same address over and over.', 'it-l10n-builder-block-events' ); ?></p>
				<?php
			}
			
			// Reset Post Data
			wp_reset_postdata();
			
			?>
				<div class="event-address-wrapper <?php echo $this->_var  ?>-default_location-custom-options active">
					<hr/>
					<p><?php _e( 'Enter the address here as you want it to display on the ' . strtolower( $settings[$this->_var . '_name'] ) . '. This address will not be used to find directions. Use the <strong>Map</strong> (below) for allowing users to get directions to your ' . strtolower( $settings[$this->_var . '_name'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
					<div class="event-address">
						<div class="address-textarea">
							<p><?php $form->add_text_area( 'event_address', array( 'style' => 'width: 400px;min-height:100px;' ) ); ?></p>
						</div>
						<div class="address-sample">
							<p><strong><?php _e( 'Example Address:', 'it-l10n-builder-block-events' ); ?></strong></p>
							<p><?php _e( 'The White House', 'it-l10n-builder-block-events' ); ?></p>
							<p><?php _e( '1600 Pennsylvania Avenue NW', 'it-l10n-builder-block-events' ); ?></p>
							<p><?php _e( 'Washington, DC 20500', 'it-l10n-builder-block-events' ); ?></p>
						</div>
					</div>
					<hr/>
					<p><?php _e( 'This map is used for displaying the exact location of your ' . strtolower( $settings[$this->_var . '_name'] ) . ' and allowing users to find directions to this location by entering their current location on the ' . strtolower( $settings[$this->_var . '_name'] ) . ' page.', 'it-l10n-builder-block-events' ); ?></p>
					
					<p><?php _e( 'Set up the map as you would like it to appear on your site. The location marker can be positioned by dragging it or clicking on a new location on the map. Once you have the location marker where you like it on the map, reposition the map so that the location marker is centered on the map. This how the marker will be centered on the map for your site.', 'it-l10n-builder-block-events' ); ?></p>
					<p><?php _e( 'To simplify finding your location quickly, you can enter a search term in the box below. For example, if your ' . strtolower( $settings[$this->_var . '_name'] ) . ' is in Oklahoma City, type "Oklahoma City" in the search field. This term <strong>will not</strong> be used on the site, it is merely used to pinpoint your location faster. To display an address on your site, enter it in the <strong>Address</strong> textarea above.', 'it-l10n-builder-block-events' ); ?></p>
					<p class="alignright"><a onclick="deleteOverlays();" style="cursor:pointer;"><?php _e( 'Remove Marker', 'it-l10n-builder-block-events' ); ?></a></p>
					<p><?php $form->add_text_box( 'search_address', array( 'placeholder' => 'Enter search terms...', 'style' => 'width: 300px;' ) ); ?><?php $form->add_button( 'locate_search_address_on_map', array( 'value' => 'Search', 'class' => 'button' ) ); ?></p>
					<div style="overflow:auto;clear:both;">
						<div id="map_canvas" style="width:100%; height:400px"></div>
					</div>
					
					<input type="hidden" id="map_center_latitude" name="map_center_latitude" value="<?php echo $options['marker_latitude']; ?>" />
					<input type="hidden" id="map_center_longitude" name="map_center_longitude" value="<?php echo $options['marker_longitude']; ?>" />
					<?php $form->add_hidden( 'map_type' ); ?>
					<?php $form->add_hidden( 'map_zoom' ); ?>
					<?php $form->add_hidden( 'marker_latitude' ); ?>
					<?php $form->add_hidden( 'marker_longitude' ); ?>
				</div>
			<?php
		} // End map meta box.
		
		// Event notification meta box.
		function render_meta_box_notification ( $post, $form, $options ) {
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			?>
				<p><?php _e( 'Check a box below to display a notification about postponement or cancelation of the ' . strtolower( $settings[$this->_var . '_name'] ) . '. This notification will display at the top of the ' . strtolower( $settings[$this->_var . '_name'] ) . ' for single ' . strtolower( $settings[$this->_var . '_name_plural'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
				<p>
					<?php $form->add_check_box( 'event_postponed' ); ?>
					<label for="event_postponed"><?php _e( 'Postponed', 'it-l10n-builder-block-events' ); ?></label>
				</p>
				<p>
					<?php $form->add_check_box( 'event_canceled' ); ?>
					<label for="event_canceled"><?php _e( ' Canceled', 'it-l10n-builder-block-events' ); ?></label>
				</p>
				<p><?php _e( 'Be sure to email registered attendees about any updates to the ' . strtolower( $settings[$this->_var . '_name'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
			<?php
		} // End notification meta box.
		
		// Event date and time meta box.
		function render_meta_box_date( $post, $form, $options ) {
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			?>
				
				<p><?php _e( 'Set a start and end date for your ' . strtolower( $settings[$this->_var . '_name'] ) . '. These dates will be displayed on your site both on the ' . strtolower( $settings[$this->_var . '_name_plural'] ) . ' list page and single page for the ' . strtolower( $settings[$this->_var . '_name'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
				
				<div class="date-time-wrapper date-wrapper">
					<div class="date-time-column">
						<h4><?php _e( 'Start Date', 'it-l10n-builder-block-events' ); ?></h4>
						<p>
							<?php $form->add_text_box( 'event_start_date', array( 'style' => 'width: 90px;', 'id' => 'event_start_date', 'class' => 'datepicker_with_icon' ) ); ?>
							<input id="event_start_date_hidden" type="hidden" name="event_start_date_hidden" />
							<label for="event_start_date">
								<img src="<?php echo ITFileUtility::get_url_from_file( dirname( $this->_file ) ); ?>/images/event-icon-inactive.png" alt="" />
							</label>
						</p>
					</div>
					<div class="date-time-column">
						<h4><?php _e( 'End Date', 'it-l10n-builder-block-events' ); ?></h4>
						<p>
							<?php $form->add_text_box( 'event_end_date', array( 'style' => 'width: 90px;', 'id' => 'event_end_date' ) ); ?>
							<input id="event_end_date_hidden" type="hidden" name="event_end_date_hidden" />
							<label for="event_end_date">
								<img src="<?php echo ITFileUtility::get_url_from_file( dirname( $this->_file ) ); ?>/images/event-icon-inactive.png" alt="" />
							</label>
						</p>
					</div>
				</div>
				
			<?php
		} // End date and time meta box.
		
		// Gravity forms meta box.
		function render_meta_box_gfrom_select( $post, $form, $options ) {
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			if ( class_exists( 'RGFormsModel' ) ) {
				
				$gforms = RGFormsModel::get_forms( 1, "title" );
				
				$gform_options = array(
					'invert-custom' => 'No Form Selected'
				);
				
				foreach ( $gforms as $gform ) {
					$gform_options[ absint( $gform->id ) ] = esc_html( $gform->title );
				}
				
				?>
					<p><?php _e( 'Select a form to use on the single ' . strtolower( $settings[$this->_var . '_name'] ) . ' page. This form will display under the map.', 'it-l10n-builder-block-events' ); ?></p>
					<p><?php _e( 'To display a form above the map,  use the content editor and Gravity Form\'s Shortcode Builder.', 'it-l10n-builder-block-events' ); ?></p>
					<p><?php $form->add_drop_down( 'gform_register', $gform_options ); ?></p>
					<div style="margin-top:10px;" class="<?php echo $this->_var  ?>-gform_register-invert-custom-options">
						<p><?php $form->add_check_box( 'gform_display_title' ); _e( ' Display Form Title?', 'it-l10n-builder-block-events' ); ?></p>
						<p><?php $form->add_check_box( 'gform_display_description' ); _e( ' Display Form Description?', 'it-l10n-builder-block-events' ); ?></p>
						<p><?php $form->add_check_box( 'gform_enable_ajax' ); _e( ' Enable Form Ajax?', 'it-l10n-builder-block-events' ); ?></p>
					</div>
				<?php
			}
			else {
				?>
					<p><?php _e( 'This block works seamlessly with Gravity Forms to provide and simple and organized method of registering for ' . strtolower( $settings[$this->_var . '_name_plural'] ) . ' and managing attendees right from the WordPress dashboard.', 'it-l10n-builder-block-events' ); ?></p>
					<p><?php printf( __( 'It looks like you do not have this awesome plugin yet (or have yet to activate it). That\'s okay. You can get it <a href="%s" target="_blank">here</a>.', 'it-l10n-builder-block-events' ), 'http://ithemes.com/gravity' ); ?></p>
				<?php
			}
		} // End Gravity Forms meta box.
		
		// Eventbrite meta box.
		function render_meta_box_eventbrite( $post, $form, $options ) {
			
			$settings = apply_filters( $this->_var . '_load_data', array() );
			
			?>
				<?php if ( empty( $settings['eventbrite_api_key'] ) || empty( $settings['eventbrite_api_user_key'] ) ) : ?>
					<p><?php _e( 'Are you a current user of <a href="http://www.eventbrite.com/" target="_blank">Eventbrite</a>? If so, you can enter API and User Key on the <a href="' . get_admin_url() . 'edit.php?post_type=' . $this->_var . '&page=bb-events-editor">Settings</a> page.', 'it-l10n-builder-block-events' ); ?></p>
				<?php else : ?>
					<p><?php _e( 'First select which one of your Eventbrite Events that you would like to link to this ' . strtolower( $settings[$this->_var . '_name'] ) . '.', 'it-l10n-builder-block-events' ); ?></p>
					
					<?php
						
						$authentication_tokens = array(
							'app_key'  => $settings['eventbrite_api_key'],
							'user_key' => $settings['eventbrite_api_user_key'],
						);
						
						$eb_client = new Eventbrite( $authentication_tokens );
						
						// For more information about the features that are available through the Eventbrite API, see http://developer.eventbrite.com/doc/
						$events = $eb_client->user_list_events();
						
						$eb_options = array(
							'invert-custom' => 'No Event Selected'
						);
						
						foreach ( $events->events as $number ) {
							$eb_options[ $number->event->id ] = $number->event->title;
						}
					?>
					<p><?php $form->add_drop_down( 'eventbrite_event', $eb_options ); ?></p>
					
					<div class="eventbrite-widget <?php echo $this->_var  ?>-eventbrite_event-invert-custom-options">
						<p><?php _e( 'Now select which widgets you would like to use on the ' . strtolower( $settings[$this->_var . '_name'] ) . ' page.', 'it-l10n-builder-block-events' ); ?></p>					
						<p><?php $form->add_check_box( 'eventbrite_button_widget' ); ?> <span><?php _e( 'Button Widget', 'it-l10n-builder-block-events' ); ?></span></p>
						<p><?php $form->add_check_box( 'eventbrite_ticket_widget' ); ?> <span><?php _e( 'Ticket Widget', 'it-l10n-builder-block-events' ); ?></span></p>
					</div>
					
				<?php endif; ?>
				
			<?php
		} // end evenbrite metabox
	}
	
	new BB_Events_Post_Type();
}
